skeptic.analysis.annotate.api


analyzed-def-entryclj

(analyzed-def-entry ns-sym analyzed)
source

annotated-nodesclj

(annotated-nodes node)
source

arglist-typesclj

(arglist-types node arity)
source

binding-initclj

(binding-init node)
source

branch-origin-kindclj

(branch-origin-kind node)
source

branch-test-assumptionclj

(branch-test-assumption node)
source

call-actual-argtypesclj

(call-actual-argtypes node)
source

call-argsclj

(call-args node)
source

call-expected-argtypesclj

(call-expected-argtypes node)
source

call-fn-nodeclj

(call-fn-node node)
source

call-node?clj

(call-node? node)
source

call-refsclj

(call-refs node)
source

callee-refclj

(callee-ref node)
source

def-init-nodeclj

(def-init-node node)
source

def-node?clj

(def-node? node)
source

def-value-nodeclj

(def-value-node node)
source

else-nodeclj

(else-node node)
source

find-nodeclj

(find-node root pred)
source

function-methodsclj

(function-methods node)
source

if-node?clj

(if-node? node)
source

invoke-opsclj

source

let-node?clj

(let-node? node)
source

local-node?clj

(local-node? node)
source

local-resolution-pathclj

(local-resolution-path local-node)
source

local-vars-contextclj

(local-vars-context node)
source

method-bodyclj

(method-body node)
source

method-result-typeclj

(method-result-type method)
source

node-arglistclj

(node-arglist node)
source

node-arglistsclj

(node-arglists node)
source

node-bindingsclj

(node-bindings node)
source

node-bodyclj

(node-body node)
source

node-childrenclj

(node-children node)
source

node-classclj

(node-class node)
source

node-exprclj

(node-expr node)
source

node-fn-typeclj

(node-fn-type node)
source

node-formclj

(node-form node)
source

node-infoclj

(node-info node)
source

node-initclj

(node-init node)
source

node-keywordclj

(node-keyword node)
source

node-locationclj

(node-location node)
source

node-methodclj

(node-method node)
source

node-nameclj

(node-name node)
source

node-opclj

(node-op node)
source

node-originclj

(node-origin node)
source

node-output-typeclj

(node-output-type node)
source

node-raw-formsclj

(node-raw-forms node)
source

node-refclj

(node-ref node)
source

node-retclj

(node-ret node)
source

node-tagclj

(node-tag node)
source

node-targetclj

(node-target node)
source

node-testclj

(node-test node)
source

node-typeclj

(node-type node)
source

node-valueclj

(node-value node)
source

node-varclj

(node-var node)
source

recur-argsclj

(recur-args node)
source

recur-node?clj

(recur-node? node)
source

resolved-def-entryclj

(resolved-def-entry resolved-defs sym)
source

resolved-def-output-typeclj

(resolved-def-output-type resolved-defs sym)
source

strip-derived-typesclj

(strip-derived-types value)
source

synthetic-binding-nodeclj

(synthetic-binding-node idx sym)
source

then-nodeclj

(then-node node)
source

typed-call-metadata-only?clj

(typed-call-metadata-only? node)
source

unwrap-with-metaclj

(unwrap-with-meta node)
source

with-typeclj

(with-type node type)

Public setter for the inferred value-type of an annotated node. Use this (not raw (assoc node :type ...)) from any code that does not own node shape.

Public setter for the inferred value-type of an annotated node.
Use this (not raw (assoc node :type ...)) from any code that does not own node shape.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries