skeptic.analysis.annotate.test-api


analyze-ns-fileclj

(analyze-ns-file dict ns-sym source-file opts)

Inputs: [dict :- s/Any ns-sym :- s/Symbol source-file :- s/Any opts :- s/Any] Returns: [aas/AnnotatedNode]

Analyze every top-level form of source-file (in ns ns-sym) on the live worker, annotate each against dict. Returns the annotated ASTs. Requires oracle/*worker-conn* bound (via the shared-worker fixture).

Inputs: [dict :- s/Any ns-sym :- s/Symbol source-file :- s/Any opts :- s/Any]
Returns: [aas/AnnotatedNode]

Analyze every top-level form of `source-file` (in ns `ns-sym`) on the live
 worker, annotate each against `dict`. Returns the annotated ASTs. Requires
 `oracle/*worker-conn*` bound (via the shared-worker fixture).
sourceraw docstring

arglist-typesclj

(arglist-types root arity)

Inputs: [root :- s/Any arity :- s/Any] Returns: s/Any

Inputs: [root :- s/Any arity :- s/Any]
Returns: s/Any
sourceraw docstring

ast-by-nameclj

(ast-by-name asts sym)

Inputs: [asts :- s/Any sym :- s/Any] Returns: s/Any

Finds the def AST whose name matches sym by short (unqualified) name. A :def node's :name may be a qualified or bare symbol depending on the analyzer pass, so both sides are normalized to their bare name before comparison (matching analyzed-def-entry's (some-> (:name node) name symbol)).

Inputs: [asts :- s/Any sym :- s/Any]
Returns: s/Any

Finds the def AST whose name matches `sym` by short (unqualified) name. A
 `:def` node's `:name` may be a qualified or bare symbol depending on the
 analyzer pass, so both sides are normalized to their bare name before
 comparison (matching `analyzed-def-entry`'s `(some-> (:name node) name symbol)`).
sourceraw docstring

child-projectionclj

(child-projection node key)

Inputs: [node :- s/Any key :- s/Any] Returns: s/Any

Inputs: [node :- s/Any key :- s/Any]
Returns: s/Any
sourceraw docstring

find-projected-nodeclj

(find-projected-node root pred)

Inputs: [root :- s/Any pred :- s/Any] Returns: s/Any

Inputs: [root :- s/Any pred :- s/Any]
Returns: s/Any
sourceraw docstring

node-by-formclj

(node-by-form ast form)

Inputs: [ast :- s/Any form :- s/Any] Returns: s/Any

Inputs: [ast :- s/Any form :- s/Any]
Returns: s/Any
sourceraw docstring

normalize-formclj

(normalize-form form)

Inputs: [form :- s/Any] Returns: s/Any

Inputs: [form :- s/Any]
Returns: s/Any
sourceraw docstring

normalize-symbolclj

(normalize-symbol value)

Inputs: [value :- s/Any] Returns: s/Any

Inputs: [value :- s/Any]
Returns: s/Any
sourceraw docstring

project-astclj

(project-ast root)

Inputs: [root :- s/Any] Returns: s/Any

Inputs: [root :- s/Any]
Returns: s/Any
sourceraw docstring

projected-nodesclj

(projected-nodes root)

Inputs: [root :- s/Any] Returns: s/Any

Inputs: [root :- s/Any]
Returns: s/Any
sourceraw docstring

stable-keysclj

source

test-const-nodeclj

(test-const-node value)

Inputs: [value :- s/Any] Returns: s/Any

Inputs: [value :- s/Any]
Returns: s/Any
sourceraw docstring

test-fn-nodeclj

(test-fn-node sym)

Inputs: [sym :- s/Any] Returns: s/Any

Inputs: [sym :- s/Any]
Returns: s/Any
sourceraw docstring

test-invoke-form-nodeclj

(test-invoke-form-node fn-node args form type)

Inputs: [fn-node :- s/Any args :- s/Any form :- s/Any type :- s/Any] Returns: s/Any

Inputs: [fn-node :- s/Any args :- s/Any form :- s/Any type :- s/Any]
Returns: s/Any
sourceraw docstring

test-invoke-nodeclj

(test-invoke-node fn-node args expected actual)

Inputs: [fn-node :- s/Any args :- s/Any expected :- s/Any actual :- s/Any] Returns: s/Any

Inputs: [fn-node :- s/Any args :- s/Any expected :- s/Any actual :- s/Any]
Returns: s/Any
sourceraw docstring

test-local-nodeclj

(test-local-node sym init)

Inputs: [sym :- s/Any init :- s/Any] Returns: s/Any

Inputs: [sym :- s/Any init :- s/Any]
Returns: s/Any
sourceraw docstring

test-static-call-nodeclj

(test-static-call-node class method)

Inputs: [class :- s/Any method :- s/Any] Returns: s/Any

Inputs: [class :- s/Any method :- s/Any]
Returns: s/Any
sourceraw docstring

test-typed-nodeclj

(test-typed-node op form type)

Inputs: [op :- s/Any form :- s/Any type :- s/Any] Returns: s/Any

Inputs: [op :- s/Any form :- s/Any type :- s/Any]
Returns: s/Any
sourceraw docstring

test-with-meta-nodeclj

(test-with-meta-node expr)

Inputs: [expr :- s/Any] Returns: s/Any

Inputs: [expr :- s/Any]
Returns: s/Any
sourceraw docstring

var->symclj

(var->sym value)

Inputs: [value :- s/Any] Returns: s/Any

Inputs: [value :- s/Any]
Returns: s/Any
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries