skeptic.analysis.cast.function


check-function-castclj

(check-function-cast run-child source-type target-type opts)

Inputs: [run-child :- (s/pred fn?) source-type :- at/SemanticType target-type :- at/SemanticType opts :- s/Any] Returns: csch/CastResult

Inputs: [run-child :- (s/pred fn?) source-type :- at/SemanticType target-type :- at/SemanticType opts :- s/Any]
Returns: csch/CastResult
sourceraw docstring

map-as-functionclj

(map-as-function map-type)

Inputs: [map-type :- at/SemanticType] Returns: at/SemanticType

A map called as a function looks up its argument: (=> union-of-value-types union-of-key-types). Really a dependent function; not modeled yet. Empty unions follow union-type's convention (Dyn).

Inputs: [map-type :- at/SemanticType]
Returns: at/SemanticType

A map called as a function looks up its argument:
 (=> union-of-value-types union-of-key-types). Really a dependent function;
 not modeled yet. Empty unions follow union-type's convention (Dyn).
sourceraw docstring

set-as-functionclj

(set-as-function set-type)

Inputs: [set-type :- at/SemanticType] Returns: at/SemanticType

A set called as a function looks up its argument, returning it on a hit and nil on a miss: (=> (maybe union-of-member-types) union-of-member-types).

Inputs: [set-type :- at/SemanticType]
Returns: at/SemanticType

A set called as a function looks up its argument, returning it on a hit
 and nil on a miss: (=> (maybe union-of-member-types) union-of-member-types).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries