(admit-malli-spec value)Validate a value as a Malli spec and return its canonical form.
Validate a value as a Malli spec and return its canonical form.
(malli-spec->type prov value)Inputs: [prov :- provs/Provenance value :- s/Any] Returns: ats/SemanticType
Convert a Malli spec to a semantic type.
Inputs: [prov :- provs/Provenance value :- s/Any] Returns: ats/SemanticType Convert a Malli spec to a semantic type.
(malli-spec-domain? value)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |