skeptic.analysis.origin


and-chain-assumptionsclj

(and-chain-assumptions node)

Assumptions for clojure.core/and expansion: (let [g e1] (if g e2' g)).

Assumptions for `clojure.core/and` expansion: (let [g e1] (if g e2' g)).
sourceraw docstring

apply-assumption-to-root-typeclj

(apply-assumption-to-root-type type assumption)
source

apply-guard-assumptionclj

(apply-guard-assumption {:keys [locals assumptions] :as ctx} assumption)
source

assumption-base-typeclj

(assumption-base-type assumption assumptions)
source

assumption-root?clj

(assumption-root? assumption root)
source

assumption-truthclj

(assumption-truth assumption assumptions)
source

branch-local-envsclj

(branch-local-envs locals assumptions conjuncts)
source

contains-key-test-assumptionclj

(contains-key-test-assumption target-node key)
source

effective-entryclj

(effective-entry sym entry assumptions)
source

entry-originclj

(entry-origin sym entry)
source

guard-assumptionclj

(guard-assumption stmt-node)
source

if-test-conjunctsclj

(if-test-conjuncts test-node locals)
source

local-binding-init-assumptionclj

(local-binding-init-assumption test-node locals)
source

local-root-originclj

(local-root-origin node)
source

node-originclj

(node-origin node)
source

opaque-originclj

(opaque-origin type)
source

opposite-assumption?clj

(opposite-assumption? left right)
source

opposite-polarityclj

(opposite-polarity assumption)
source

origin-typeclj

(origin-type origin assumptions)
source

refine-locals-for-assumptionclj

(refine-locals-for-assumption locals assumptions)
source

refine-root-typeclj

(refine-root-type root assumptions)
source

root-originclj

(root-origin sym type)
source

same-assumption-proposition?clj

(same-assumption-proposition? a b)

Same narrowed fact on the same root, ignoring branch polarity.

Same narrowed fact on the same root, ignoring branch polarity.
sourceraw docstring

same-assumption?clj

(same-assumption? left right)
source

test->assumptionclj

(test->assumption test-node)
source

typed-entryclj

(typed-entry entry)
source

cljdoc builds & hosts documentation for Clojure/Script libraries