Source discovery for cljs/cljc files in a Leiningen project. Reads :source-paths and :test-paths from the project map, plus any cljsbuild build :source-paths if present, and walks them for cljs/cljc files.
Source discovery for cljs/cljc files in a Leiningen project. Reads :source-paths and :test-paths from the project map, plus any cljsbuild build :source-paths if present, and walks them for cljs/cljc files.
(discover-sources project)Inputs: [project] Returns: discover/DiscoverySources
Inputs: [project] Returns: discover/DiscoverySources
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |