Clojure only.

skeptic.output


printerclj

(printer opts)

Inputs: [opts :- copts/CheckProjectOpts] Returns: s/Any

Return the printer lifecycle map for the given opts. Porcelain emits JSONL; otherwise the human-readable text printer.

Inputs: [opts :- copts/CheckProjectOpts]
Returns: s/Any

Return the printer lifecycle map for the given opts.
Porcelain emits JSONL; otherwise the human-readable text printer.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries