(with-type node type)Public setter for the inferred value-type of an annotated node. Use this (not raw (assoc node :type ...)) from any code that does not own node shape.
Public setter for the inferred value-type of an annotated node. Use this (not raw (assoc node :type ...)) from any code that does not own node shape.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |