(add-descriptor-entry descriptor entry)Inputs: [descriptor :- #:s{Keyword s/Any} entry :- #:s{Keyword s/Any}] Returns: #:s{Keyword s/Any}
Inputs: [descriptor :- #:s{Keyword s/Any} entry :- #:s{Keyword s/Any}]
Returns: #:s{Keyword s/Any}(candidate-value-type candidates)Inputs: [candidates :- [s/Any]] Returns: (s/maybe ats/SemanticType)
Inputs: [candidates :- [s/Any]] Returns: (s/maybe ats/SemanticType)
(descriptor-entry entry-key entry-value kind)Inputs: [entry-key :- s/Any entry-value :- s/Any kind :- s/Keyword] Returns: #:s{Keyword s/Any}
Inputs: [entry-key :- s/Any entry-value :- s/Any kind :- s/Keyword]
Returns: #:s{Keyword s/Any}(domain-key-candidates descriptor key-type)Inputs: [descriptor :- #:s{Keyword s/Any} key-type :- ats/SemanticType] Returns: [s/Any]
Inputs: [descriptor :- #:s{Keyword s/Any} key-type :- ats/SemanticType]
Returns: [s/Any](domain-key-query type)(domain-key-query type source-form)Inputs: ([type :- ats/SemanticType] [type :- ats/SemanticType source-form :- s/Any]) Returns: #:s{Keyword s/Any}
Inputs: ([type :- ats/SemanticType] [type :- ats/SemanticType source-form :- s/Any])
Returns: #:s{Keyword s/Any}(effective-exact-entries descriptor)Inputs: [descriptor :- #:s{Keyword s/Any}] Returns: s/Any
Inputs: [descriptor :- #:s{Keyword s/Any}]
Returns: s/Any(exact-entry-kind key-type)Inputs: [key-type :- ats/SemanticType] Returns: s/Keyword
Inputs: [key-type :- ats/SemanticType] Returns: s/Keyword
(exact-key-candidates descriptor exact-value)Inputs: [descriptor :- #:s{Keyword s/Any} exact-value :- s/Any] Returns: [s/Any]
Inputs: [descriptor :- #:s{Keyword s/Any} exact-value :- s/Any]
Returns: [s/Any](exact-key-entry descriptor exact-value)Inputs: [descriptor :- #:s{Keyword s/Any} exact-value :- s/Any] Returns: (s/maybe #:s{Keyword s/Any})
Inputs: [descriptor :- #:s{Keyword s/Any} exact-value :- s/Any]
Returns: (s/maybe #:s{Keyword s/Any})(exact-key-query prov value)(exact-key-query prov value source-form)Inputs: ([prov :- provs/Provenance value :- s/Any] [prov :- provs/Provenance value :- s/Any source-form :- s/Any]) Returns: #:s{Keyword s/Any}
Inputs: ([prov :- provs/Provenance value :- s/Any] [prov :- provs/Provenance value :- s/Any source-form :- s/Any])
Returns: #:s{Keyword s/Any}(exact-key-query? query)Inputs: [query :- s/Any] Returns: s/Bool
Inputs: [query :- s/Any] Returns: s/Bool
(finite-exact-key-values type)Inputs: [type :- ats/SemanticType] Returns: (s/maybe #{s/Any})
Inputs: [type :- ats/SemanticType]
Returns: (s/maybe #{s/Any})(key-domain-covered? source-key target-key)Inputs: [source-key :- ats/SemanticType target-key :- ats/SemanticType] Returns: s/Bool
Inputs: [source-key :- ats/SemanticType target-key :- ats/SemanticType] Returns: s/Bool
(key-domain-overlap? source-key target-key)Inputs: [source-key :- ats/SemanticType target-key :- ats/SemanticType] Returns: s/Bool
Inputs: [source-key :- ats/SemanticType target-key :- ats/SemanticType] Returns: s/Bool
(map-entry-descriptor entries)Inputs: [entries :- s/Any] Returns: #:s{Keyword s/Any}
Inputs: [entries :- s/Any]
Returns: #:s{Keyword s/Any}(map-get-type m key)(map-get-type m key default)Inputs: ([m :- ats/SemanticType key :- s/Any] [m :- ats/SemanticType key :- s/Any default :- s/Any]) Returns: (s/maybe ats/SemanticType)
Inputs: ([m :- ats/SemanticType key :- s/Any] [m :- ats/SemanticType key :- s/Any default :- s/Any]) Returns: (s/maybe ats/SemanticType)
(map-key-query? query)Inputs: [query :- s/Any] Returns: s/Bool
Inputs: [query :- s/Any] Returns: s/Bool
(map-lookup-candidates entries key-query)Inputs: [entries :- s/Any key-query :- s/Any] Returns: [s/Any]
Inputs: [entries :- s/Any key-query :- s/Any] Returns: [s/Any]
(map-type-at-path root-type path)Inputs: [root-type :- ats/SemanticType path :- [s/Any]] Returns: (s/maybe ats/SemanticType)
Return the Type stored at path within root-type, descending through
map/union/maybe layers. Returns nil when the path cannot be resolved.
Inputs: [root-type :- ats/SemanticType path :- [s/Any]] Returns: (s/maybe ats/SemanticType) Return the Type stored at `path` within `root-type`, descending through map/union/maybe layers. Returns nil when the path cannot be resolved.
(merge-map-types anchor-prov types)Inputs: [anchor-prov :- provs/Provenance types :- [ats/SemanticType]] Returns: ats/SemanticType
Inputs: [anchor-prov :- provs/Provenance types :- [ats/SemanticType]] Returns: ats/SemanticType
(query-key-type query)Inputs: [query :- s/Any] Returns: ats/SemanticType
Inputs: [query :- s/Any] Returns: ats/SemanticType
(refine-by-contains-key type key polarity)Inputs: [type :- ats/SemanticType key :- s/Any polarity :- s/Bool] Returns: ats/SemanticType
Inputs: [type :- ats/SemanticType key :- s/Any polarity :- s/Bool] Returns: ats/SemanticType
(refine-map-path-by-predicate root-type path pred-info polarity)Inputs: [root-type :- ats/SemanticType path :- [s/Any] pred-info :- #:s{Keyword s/Any} polarity :- s/Bool] Returns: ats/SemanticType
Refine root-type by asserting that the value at path satisfies
pred-info ({:pred kw :class cls-or-nil}) with the given polarity.
Inputs: [root-type :- ats/SemanticType path :- [s/Any] pred-info :- #:s{Keyword s/Any} polarity :- s/Bool]
Returns: ats/SemanticType
Refine `root-type` by asserting that the value at `path` satisfies
`pred-info` (`{:pred kw :class cls-or-nil}`) with the given `polarity`.(refine-map-path-by-values root-type path values polarity)Inputs: [root-type :- ats/SemanticType path :- [s/Any] values :- [s/Any] polarity :- s/Bool] Returns: ats/SemanticType
Refine root-type by asserting that the value at the nested path path
equals one of values. polarity true selects matching values; false
selects non-matching.
Inputs: [root-type :- ats/SemanticType path :- [s/Any] values :- [s/Any] polarity :- s/Bool] Returns: ats/SemanticType Refine `root-type` by asserting that the value at the nested path `path` equals one of `values`. `polarity` true selects matching values; false selects non-matching.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |