(and-chain-assumptions node)Assumptions for clojure.core/and expansion: (let [g e1] (if g e2' g)).
Assumptions for `clojure.core/and` expansion: (let [g e1] (if g e2' g)).
(apply-guard-assumption {:keys [locals assumptions] :as ctx} assumption)(same-assumption-proposition? a b)Same narrowed fact on the same root, ignoring branch polarity.
Same narrowed fact on the same root, ignoring branch polarity.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |