(predicate-form->descriptor pred-form ns-sym accessor-summaries)Recognize classifier predicates against the project-wide accessor-summaries map; ns-sym is the defining ns of the schema that owns the pred-form, used to qualify bare classifier symbols. Returns {:path ... :values [...]} or nil.
Recognize classifier predicates against the project-wide accessor-summaries
map; ns-sym is the defining ns of the schema that owns the pred-form, used
to qualify bare classifier symbols. Returns {:path ... :values [...]} or nil.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |