skeptic.cljs.schema-interpreter

sci-sandboxed interpretation of post-macroexpansion Plumatic Schema forms collected from cljs ASTs.

The sci context exposes schema.core as the only allowlisted user namespace; sci interprets the form by applying Plumatic's real JVM functions and returns real Plumatic Schema records. Symbols outside the allowlist (and sci's default clojure.core surface) cannot be resolved, so the interpreter cannot execute arbitrary user code.

sci-sandboxed interpretation of post-macroexpansion Plumatic Schema forms
collected from cljs ASTs.

The sci context exposes `schema.core` as the only allowlisted user
namespace; sci interprets the form by applying Plumatic's real JVM
functions and returns real Plumatic Schema records. Symbols outside
the allowlist (and sci's default clojure.core surface) cannot be
resolved, so the interpreter cannot execute arbitrary user code.
raw docstring

interpret-schema-formclj

(interpret-schema-form form)

Inputs: [form :- s/Any] Returns: s/Any

Inputs: [form :- s/Any]
Returns: s/Any
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries