(printer opts)Inputs: [opts :- copts/CheckProjectOpts] Returns: s/Any
Return the printer lifecycle map for the given opts. Porcelain emits JSONL; otherwise the human-readable text printer.
Inputs: [opts :- copts/CheckProjectOpts] Returns: s/Any Return the printer lifecycle map for the given opts. Porcelain emits JSONL; otherwise the human-readable text printer.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |