Host-side JVM Plumatic admission from worker-captured evaluated schema values. The worker loads the project namespace and reads Var metadata; the host decodes the EDN schema payload and feeds the existing SchemaDesc builder. No source-form schema interpretation and no host project namespace loading.
Host-side JVM Plumatic admission from worker-captured evaluated schema values. The worker loads the project namespace and reads Var metadata; the host decodes the EDN schema payload and feeds the existing SchemaDesc builder. No source-form schema interpretation and no host project namespace loading.
(ns-schema-results-clj ns-sym entries)Per-namespace JVM Plumatic admission from worker-shipped clj-state entries.
Per-namespace JVM Plumatic admission from worker-shipped clj-state entries.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |